#!/bin/sh
###############################################################################
#
# Script to import objects from a CSV file to Cacti
#
# Written by Stephen Amstutz <stephen[-a-t-]stutz.co.uk>
#
###############################################################################
#
# Assign Variables
#
treename="MyTree"
filename="objects.txt"
userid="1"
ro_comm_string="MyString"
#
###############################################################################
#
# Add a tree
#
treeid=$(./add_tree.php --type tree --name $treename --sort-method n | grep tree-id | awk -F"(" '{print $2}' | tr -d ')')
echo
echo Created Tree $treename
echo Tree-ID $treeid
#
###############################################################################
#
# Assign permissions for the tree
#
./add_perms.php --user-id $userid --item-type tree --item-id $treeid
echo
echo Added permissions for User-ID $userid on Tree $treename
#
###############################################################################
#
# Prepare file for parsing
#
prepfilename=$filename".prep"
sed -e 's/"//g' $filename > $prepfilename
#
###############################################################################
#
# Parse objects file to create devices and graphs
#
grep -i $treename $prepfilename | awk '{print $1,$2}' | while read devicename deviceaddress; do
#
###############################################################################
#
# Create device
#
deviceid=$(./add_device.php 5 $devicename $deviceaddress $ro_comm_string 2 0 | grep device-id | awk -F"(" '{print $2}' | tr -d ')')
echo
echo Created Device $devicename Device-ID $deviceid
#
###############################################################################
#
# Create node to place device in tree
#
nodeid=$(./add_tree.php --type node --node-type host --tree-id $treeid --parent-node 0 --host-id $deviceid --host-group-style 1 | grep node-id | awk -F"(" '{print $2}' | tr -d ')')
echo
echo Created Node-ID $nodeid for $devicename
#
###############################################################################
#
# Create graph for Availability
#
bothid=$(./add_graphs.php --graph-type cg --graph-template-id 37 --host-id $deviceid | grep graph-id | awk -F"(" '{print $2 $3}')
graphid=$(echo $bothid | awk '{print $1}' | tr -d ')')
rraid=$(echo $bothid | awk '{print $4}' | tr -d ')')
echo
echo Created Graph-ID $graphid for Availability on $devicename
#
# Add graph to node
#
./add_tree.php --type node --node-type graph --tree-id $treeid --parent-node $nodeid --graph-id $graphid --rra-id $rraid
echo
echo Added Graph-ID $graphid to Node-ID $nodeid
#
################################################################################
#
# Create graph for CPU Usage
#
bothid=$(./add_graphs.php --graph-type cg --graph-template-id 18 --host-id $deviceid | grep graph-id | awk -F"(" '{print $2 $3}')
graphid=$(echo $bothid | awk '{print $1}' | tr -d ')')
rraid=$(echo $bothid | awk '{print $4}' | tr -d ')')
echo
echo Created Graph-ID $graphid for CPU Usage on $devicename
#
# Add graph to node
#
./add_tree.php --type node --node-type graph --tree-id $treeid --parent-node $nodeid --graph-id $graphid --rra-id $rraid
echo
echo Added Graph-ID $graphid to Node-ID $nodeid
#
#################################################################################
#
# Create graph for ATM0
#
bothid=$(./add_graphs.php --graph-type ds --graph-template-id 2 --host-id $deviceid --snmp-query-id 1 --snmp-query-type-id 14 --snmp-field ifDescr --snmp-value ATM0 | grep graph-id | awk -F"(" '{print $2 $3}')
graphid=$(echo $bothid | awk '{print $1}' | tr -d ')')
rraid=$(echo $bothid | awk '{print $4}' | tr -d ')')
echo
echo Created Graph-ID $graphid for Dialler0 on $devicename
#
# Add graph to node
#
./add_tree.php --type node --node-type graph --tree-id $treeid --parent-node $nodeid --graph-id $graphid --rra-id $rraid
echo
echo Added Graph-ID $graphid to Node-ID $nodeid
done
###############################################################################
